window.Gleam.initSearch([{"doc":"bucket","title":"bucket","content":"# bucket\n\nGleam S3 API client, suitable for AWS S3, Garage, Minio, Storj,\nBackblaze B2, Cloudflare R2, Ceph, Wasabi, and so on!\n\n[![Package Version](https://img.shields.io/hexpm/v/bucket)](https://hex.pm/packages/bucket)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/bucket/)\n\nThis package uses the _sans-io_ approach, meaning it does not send HTTP requests\nitself, instead it gives you functions for creating HTTP requests for and\ndecoding HTTP responses from an S3 API, and you send the requests with a HTTP\nclient of your choosing.\n\nThis HTTP client independence gives you full control over HTTP, and means this\nlibrary can be used on both the Erlang and JavaScript runtimes.\n\n```sh\ngleam add bucket@1\n```\n```gleam\nimport bucket\nimport bucket/get_object.{Found}\nimport gleam/bit_array\nimport gleam/http.{Https}\nimport gleam/io\nimport httpc\n\n/// This program downloads an object and prints the string contents.\n///\n/// It uses `let assert` to handle errors, but in a real program you&#39;d most\n/// likely want to use pattern matching or the `gleam/result` module to handle\n/// the error values gracefully.\n///\npub fn main() {\n  let creds = bucket.credentials(\n    host: &quot;s3-api-host.example.com&quot;,\n    access_key_id: &quot;YOUR_ACCESS_KEY&quot;,\n    secret_access_key: &quot;YOUR_SECRET_ACCESS_KEY&quot;,\n  )\n\n  // Create a HTTP request to download an object\n  let request =\n    get_object.request(bucket: &quot;my-bucket&quot;, key: &quot;my/key.txt&quot;)\n    |&gt; get_object.build()\n\n  // Send the HTTP request\n  let assert Ok(response) = httpc.send_bits(request)\n\n  // Decode the response from the API\n  let assert Ok(Found(object)) = get_object.response(response)\n\n  // Print the string contents\n  let assert Ok(text) = bit_array.from_string(object)\n  io.println(text)\n}\n```\n\nThe following endpoints are supported:\n\n- [CreateBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html)\n- [DeleteBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html)\n- [DeleteObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html)\n- [DeleteObjects](https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjects.html)\n- [GetObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html)\n- [HeadBucket](https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadBucket.html)\n- [HeadObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadObject.html)\n- [ListBuckets](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html)\n- [ListObjects](https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjects.html)\n- [PutObject](https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html)\n- [CreateMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html)\n- [UploadPart](https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html)\n- [CompleteMultipartUpload](https://docs.aws.amazon.com/AmazonS3/latest/API/API_CompleteMultipartUpload.html)\n\nFurther documentation can be found at &lt;https://hexdocs.pm/bucket&gt;.\n","url":"index.html"},{"doc":"bucket","title":"Bucket","content":"pub type Bucket {\n  Bucket(name: String, creation_date: String)\n}\n\nBucket(name: String, creation_date: String)\n\n\nSynonyms:\nbucket.Bucket\nbucket Bucket","url":"bucket.html#Bucket"},{"doc":"bucket","title":"BucketError","content":"pub type BucketError {\n  InvalidXmlSyntaxError(String)\n  UnexpectedXmlFormatError(String)\n  UnexpectedResponseError(Response(BitArray))\n  S3Error(http_status: Int, error: ErrorObject)\n}\n\nInvalidXmlSyntaxError(String)\n\n\nUnexpectedXmlFormatError(String)\n\n\nUnexpectedResponseError(Response(BitArray))\n\n\nS3Error(http_status: Int, error: ErrorObject)\n\n\nSynonyms:\nbucket.BucketError\nbucket BucketError","url":"bucket.html#BucketError"},{"doc":"bucket","title":"Credentials","content":"pub type Credentials {\n  Credentials(\n    scheme: Scheme,\n    port: Option(Int),\n    host: String,\n    region: String,\n    access_key_id: String,\n    secret_access_key: String,\n  )\n}\n The creds used to connect to an S3 API.\nCredentials(\n  scheme: Scheme,\n  port: Option(Int),\n  host: String,\n  region: String,\n  access_key_id: String,\n  secret_access_key: String,\n)\n\n\nSynonyms:\nbucket.Credentials\nbucket Credentials","url":"bucket.html#Credentials"},{"doc":"bucket","title":"ErrorObject","content":"pub type ErrorObject {\n  ErrorObject(\n    code: String,\n    message: String,\n    resource: String,\n    request_id: String,\n  )\n}\n An error from S3.\nErrorObject(\n  code: String,\n  message: String,\n  resource: String,\n  request_id: String,\n)\n\n\nSynonyms:\nbucket.ErrorObject\nbucket ErrorObject","url":"bucket.html#ErrorObject"},{"doc":"bucket","title":"credentials","content":"pub fn credentials(\n  host: String,\n  access_key_id: String,\n  secret_access_key: String,\n) -&gt; Credentials\n\nSynonyms:\nbucket.credentials\nbucket credentials","url":"bucket.html#credentials"},{"doc":"bucket","title":"with_port","content":"pub fn with_port(creds: Credentials, port: Int) -&gt; Credentials\n Set the port for the credentials.\nSynonyms:\nbucket.with_port\nbucket with_port","url":"bucket.html#with_port"},{"doc":"bucket","title":"with_region","content":"pub fn with_region(\n  creds: Credentials,\n  region: String,\n) -&gt; Credentials\n Set the region for the credentials.\nSynonyms:\nbucket.with_region\nbucket with_region","url":"bucket.html#with_region"},{"doc":"bucket","title":"with_scheme","content":"pub fn with_scheme(\n  creds: Credentials,\n  scheme: Scheme,\n) -&gt; Credentials\n Set the scheme for the credentials. You should use HTTPS unless not possible.\nSynonyms:\nbucket.with_scheme\nbucket with_scheme","url":"bucket.html#with_scheme"},{"doc":"bucket","title":"bucket","content":"","url":"bucket.html"},{"doc":"bucket/complete_multipart_upload","title":"CompleteMultipartUploadResult","content":"pub type CompleteMultipartUploadResult {\n  CompleteMultipartUploadResult(\n    location: String,\n    bucket: String,\n    key: String,\n    etag: String,\n  )\n}\n\nCompleteMultipartUploadResult(\n  location: String,\n  bucket: String,\n  key: String,\n  etag: String,\n)\n\n\nSynonyms:\nbucket/complete_multipart_upload.CompleteMultipartUploadResult\nbucket/complete_multipart_upload CompleteMultipartUploadResult","url":"bucket/complete_multipart_upload.html#CompleteMultipartUploadResult"},{"doc":"bucket/complete_multipart_upload","title":"Part","content":"pub type Part {\n  Part(part_number: Int, etag: String)\n}\n\nPart(part_number: Int, etag: String)\n\n\nSynonyms:\nbucket/complete_multipart_upload.Part\nbucket/complete_multipart_upload Part","url":"bucket/complete_multipart_upload.html#Part"},{"doc":"bucket/complete_multipart_upload","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(\n    bucket: String,\n    key: String,\n    upload_id: String,\n    parts: List(Part),\n  )\n}\n The parameters for the API request\nRequestBuilder(\n  bucket: String,\n  key: String,\n  upload_id: String,\n  parts: List(Part),\n)\n\n\nSynonyms:\nbucket/complete_multipart_upload.RequestBuilder\nbucket/complete_multipart_upload RequestBuilder","url":"bucket/complete_multipart_upload.html#RequestBuilder"},{"doc":"bucket/complete_multipart_upload","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/complete_multipart_upload.build\nbucket/complete_multipart_upload build","url":"bucket/complete_multipart_upload.html#build"},{"doc":"bucket/complete_multipart_upload","title":"request","content":"pub fn request(\n  bucket bucket: String,\n  key key: String,\n  upload_id upload_id: String,\n  parts parts: List(Part),\n) -&gt; RequestBuilder\n\nSynonyms:\nbucket/complete_multipart_upload.request\nbucket/complete_multipart_upload request","url":"bucket/complete_multipart_upload.html#request"},{"doc":"bucket/complete_multipart_upload","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(CompleteMultipartUploadResult, BucketError)\n\nSynonyms:\nbucket/complete_multipart_upload.response\nbucket/complete_multipart_upload response","url":"bucket/complete_multipart_upload.html#response"},{"doc":"bucket/complete_multipart_upload","title":"bucket/complete_multipart_upload","content":" &lt;https://docs.aws.amazon.com/AmazonS3/latest/API/API_CompleteMultipartUpload.html&gt;\n\n CompleteMultipartUpload operation creates a new object by combining the specified parts. You may omit any number of parts, but they must be specified in ascending order.","url":"bucket/complete_multipart_upload.html"},{"doc":"bucket/create_bucket","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(name: String, region: Option(String))\n}\n The parameters for the API request\nRequestBuilder(name: String, region: Option(String))\n\n\nSynonyms:\nbucket/create_bucket.RequestBuilder\nbucket/create_bucket RequestBuilder","url":"bucket/create_bucket.html#RequestBuilder"},{"doc":"bucket/create_bucket","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/create_bucket.build\nbucket/create_bucket build","url":"bucket/create_bucket.html#build"},{"doc":"bucket/create_bucket","title":"region","content":"pub fn region(\n  builder: RequestBuilder,\n  region: String,\n) -&gt; RequestBuilder\n The region to create the bucket in. Defaults to the region from the\n credentials if no region is specifier.\n\nSynonyms:\nbucket/create_bucket.region\nbucket/create_bucket region","url":"bucket/create_bucket.html#region"},{"doc":"bucket/create_bucket","title":"request","content":"pub fn request(name name: String) -&gt; RequestBuilder\n\nSynonyms:\nbucket/create_bucket.request\nbucket/create_bucket request","url":"bucket/create_bucket.html#request"},{"doc":"bucket/create_bucket","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(Nil, BucketError)\n\nSynonyms:\nbucket/create_bucket.response\nbucket/create_bucket response","url":"bucket/create_bucket.html#response"},{"doc":"bucket/create_bucket","title":"bucket/create_bucket","content":"","url":"bucket/create_bucket.html"},{"doc":"bucket/create_multipart_upload","title":"CreateMultipartUploadResult","content":"pub type CreateMultipartUploadResult {\n  CreateMultipartUploadResult(\n    bucket: String,\n    key: String,\n    upload_id: String,\n  )\n}\n\nCreateMultipartUploadResult(\n  bucket: String,\n  key: String,\n  upload_id: String,\n)\n\n\nSynonyms:\nbucket/create_multipart_upload.CreateMultipartUploadResult\nbucket/create_multipart_upload CreateMultipartUploadResult","url":"bucket/create_multipart_upload.html#CreateMultipartUploadResult"},{"doc":"bucket/create_multipart_upload","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(bucket: String, key: String)\n}\n The parameters for the API request\nRequestBuilder(bucket: String, key: String)\n\n\nSynonyms:\nbucket/create_multipart_upload.RequestBuilder\nbucket/create_multipart_upload RequestBuilder","url":"bucket/create_multipart_upload.html#RequestBuilder"},{"doc":"bucket/create_multipart_upload","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/create_multipart_upload.build\nbucket/create_multipart_upload build","url":"bucket/create_multipart_upload.html#build"},{"doc":"bucket/create_multipart_upload","title":"request","content":"pub fn request(\n  bucket bucket: String,\n  key key: String,\n) -&gt; RequestBuilder\n\nSynonyms:\nbucket/create_multipart_upload.request\nbucket/create_multipart_upload request","url":"bucket/create_multipart_upload.html#request"},{"doc":"bucket/create_multipart_upload","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(CreateMultipartUploadResult, BucketError)\n\nSynonyms:\nbucket/create_multipart_upload.response\nbucket/create_multipart_upload response","url":"bucket/create_multipart_upload.html#response"},{"doc":"bucket/create_multipart_upload","title":"bucket/create_multipart_upload","content":" &lt;https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateMultipartUpload.html&gt;","url":"bucket/create_multipart_upload.html"},{"doc":"bucket/delete_bucket","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(\n    name: String,\n    expected_bucket_owner: Option(String),\n  )\n}\n The parameters for the API request\nRequestBuilder(\n  name: String,\n  expected_bucket_owner: Option(String),\n)\n\n\nSynonyms:\nbucket/delete_bucket.RequestBuilder\nbucket/delete_bucket RequestBuilder","url":"bucket/delete_bucket.html#RequestBuilder"},{"doc":"bucket/delete_bucket","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/delete_bucket.build\nbucket/delete_bucket build","url":"bucket/delete_bucket.html#build"},{"doc":"bucket/delete_bucket","title":"expected_bucket_owner","content":"pub fn expected_bucket_owner(\n  builder: RequestBuilder,\n  expected_bucket_owner: String,\n) -&gt; RequestBuilder\n The account ID of the expected bucket owner. If the account ID that you\n provide does not match the actual owner of the bucket, the request fails with\n the HTTP status code 403 Forbidden (access denied).\n\nSynonyms:\nbucket/delete_bucket.expected_bucket_owner\nbucket/delete_bucket expected_bucket_owner","url":"bucket/delete_bucket.html#expected_bucket_owner"},{"doc":"bucket/delete_bucket","title":"request","content":"pub fn request(name name: String) -&gt; RequestBuilder\n\nSynonyms:\nbucket/delete_bucket.request\nbucket/delete_bucket request","url":"bucket/delete_bucket.html#request"},{"doc":"bucket/delete_bucket","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(Nil, BucketError)\n\nSynonyms:\nbucket/delete_bucket.response\nbucket/delete_bucket response","url":"bucket/delete_bucket.html#response"},{"doc":"bucket/delete_bucket","title":"bucket/delete_bucket","content":"","url":"bucket/delete_bucket.html"},{"doc":"bucket/delete_object","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(bucket: String, key: String)\n}\n The parameters for the API request\nRequestBuilder(bucket: String, key: String)\n\n\nSynonyms:\nbucket/delete_object.RequestBuilder\nbucket/delete_object RequestBuilder","url":"bucket/delete_object.html#RequestBuilder"},{"doc":"bucket/delete_object","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/delete_object.build\nbucket/delete_object build","url":"bucket/delete_object.html#build"},{"doc":"bucket/delete_object","title":"request","content":"pub fn request(\n  bucket bucket: String,\n  key key: String,\n) -&gt; RequestBuilder\n\nSynonyms:\nbucket/delete_object.request\nbucket/delete_object request","url":"bucket/delete_object.html#request"},{"doc":"bucket/delete_object","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(Nil, BucketError)\n\nSynonyms:\nbucket/delete_object.response\nbucket/delete_object response","url":"bucket/delete_object.html#response"},{"doc":"bucket/delete_object","title":"bucket/delete_object","content":"","url":"bucket/delete_object.html"},{"doc":"bucket/delete_objects","title":"Deleted","content":"pub type Deleted {\n  Deleted(key: String, version_id: String)\n}\n\nDeleted(key: String, version_id: String)\n\n\nSynonyms:\nbucket/delete_objects.Deleted\nbucket/delete_objects Deleted","url":"bucket/delete_objects.html#Deleted"},{"doc":"bucket/delete_objects","title":"ObjectIdentifier","content":"pub type ObjectIdentifier {\n  ObjectIdentifier(key: String, version_id: Option(String))\n}\n\nObjectIdentifier(key: String, version_id: Option(String))\n\n\nSynonyms:\nbucket/delete_objects.ObjectIdentifier\nbucket/delete_objects ObjectIdentifier","url":"bucket/delete_objects.html#ObjectIdentifier"},{"doc":"bucket/delete_objects","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(bucket: String, objects: List(ObjectIdentifier))\n}\n The parameters for the API request\nRequestBuilder(bucket: String, objects: List(ObjectIdentifier))\n\n\nSynonyms:\nbucket/delete_objects.RequestBuilder\nbucket/delete_objects RequestBuilder","url":"bucket/delete_objects.html#RequestBuilder"},{"doc":"bucket/delete_objects","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/delete_objects.build\nbucket/delete_objects build","url":"bucket/delete_objects.html#build"},{"doc":"bucket/delete_objects","title":"request","content":"pub fn request(\n  bucket: String,\n  objects: List(ObjectIdentifier),\n) -&gt; RequestBuilder\n\nSynonyms:\nbucket/delete_objects.request\nbucket/delete_objects request","url":"bucket/delete_objects.html#request"},{"doc":"bucket/delete_objects","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(List(Result(Deleted, ErrorObject)), BucketError)\n\nSynonyms:\nbucket/delete_objects.response\nbucket/delete_objects response","url":"bucket/delete_objects.html#response"},{"doc":"bucket/delete_objects","title":"bucket/delete_objects","content":"","url":"bucket/delete_objects.html"},{"doc":"bucket/get_object","title":"Outcome","content":"pub type Outcome(body) {\n  Found(body)\n  NotFound\n}\n\nFound(body)\n\n\nNotFound\n\n\nSynonyms:\nbucket/get_object.Outcome\nbucket/get_object Outcome","url":"bucket/get_object.html#Outcome"},{"doc":"bucket/get_object","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(bucket: String, key: String)\n}\n The parameters for the API request\nRequestBuilder(bucket: String, key: String)\n\n\nSynonyms:\nbucket/get_object.RequestBuilder\nbucket/get_object RequestBuilder","url":"bucket/get_object.html#RequestBuilder"},{"doc":"bucket/get_object","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/get_object.build\nbucket/get_object build","url":"bucket/get_object.html#build"},{"doc":"bucket/get_object","title":"request","content":"pub fn request(\n  bucket bucket: String,\n  key key: String,\n) -&gt; RequestBuilder\n\nSynonyms:\nbucket/get_object.request\nbucket/get_object request","url":"bucket/get_object.html#request"},{"doc":"bucket/get_object","title":"response","content":"pub fn response(\n  response: Response(a),\n) -&gt; Result(Outcome(a), BucketError)\n\nSynonyms:\nbucket/get_object.response\nbucket/get_object response","url":"bucket/get_object.html#response"},{"doc":"bucket/get_object","title":"bucket/get_object","content":" &lt;https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html&gt;","url":"bucket/get_object.html"},{"doc":"bucket/head_bucket","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(\n    name: String,\n    expected_bucket_owner: Option(String),\n  )\n}\n The parameters for the API request\nRequestBuilder(\n  name: String,\n  expected_bucket_owner: Option(String),\n)\n\n\nSynonyms:\nbucket/head_bucket.RequestBuilder\nbucket/head_bucket RequestBuilder","url":"bucket/head_bucket.html#RequestBuilder"},{"doc":"bucket/head_bucket","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/head_bucket.build\nbucket/head_bucket build","url":"bucket/head_bucket.html#build"},{"doc":"bucket/head_bucket","title":"expected_bucket_owner","content":"pub fn expected_bucket_owner(\n  builder: RequestBuilder,\n  expected_bucket_owner: String,\n) -&gt; RequestBuilder\n The account ID of the expected bucket owner. If the account ID that you\n provide does not match the actual owner of the bucket, the request fails with\n the HTTP status code 403 Forbidden (access denied).\n\nSynonyms:\nbucket/head_bucket.expected_bucket_owner\nbucket/head_bucket expected_bucket_owner","url":"bucket/head_bucket.html#expected_bucket_owner"},{"doc":"bucket/head_bucket","title":"request","content":"pub fn request(name name: String) -&gt; RequestBuilder\n\nSynonyms:\nbucket/head_bucket.request\nbucket/head_bucket request","url":"bucket/head_bucket.html#request"},{"doc":"bucket/head_bucket","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(Bool, BucketError)\n\nSynonyms:\nbucket/head_bucket.response\nbucket/head_bucket response","url":"bucket/head_bucket.html#response"},{"doc":"bucket/head_bucket","title":"bucket/head_bucket","content":" &lt;https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadBucket.html&gt;","url":"bucket/head_bucket.html"},{"doc":"bucket/head_object","title":"Outcome","content":"pub type Outcome {\n  Found\n  NotFound\n  PreconditionFailed\n}\n\nFound\n\n\nNotFound\n\n\nPreconditionFailed\n\n\nSynonyms:\nbucket/head_object.Outcome\nbucket/head_object Outcome","url":"bucket/head_object.html#Outcome"},{"doc":"bucket/head_object","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(\n    bucket: String,\n    key: String,\n    if_match: Option(String),\n    expected_bucket_owner: Option(String),\n  )\n}\n The parameters for the API request\nRequestBuilder(\n  bucket: String,\n  key: String,\n  if_match: Option(String),\n  expected_bucket_owner: Option(String),\n)\n\n\nSynonyms:\nbucket/head_object.RequestBuilder\nbucket/head_object RequestBuilder","url":"bucket/head_object.html#RequestBuilder"},{"doc":"bucket/head_object","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/head_object.build\nbucket/head_object build","url":"bucket/head_object.html#build"},{"doc":"bucket/head_object","title":"expected_bucket_owner","content":"pub fn expected_bucket_owner(\n  builder: RequestBuilder,\n  expected_bucket_owner: String,\n) -&gt; RequestBuilder\n The account ID of the expected bucket owner. If the account ID that you\n provide does not match the actual owner of the bucket, the request fails with\n the HTTP status code 403 Forbidden (access denied).\n\nSynonyms:\nbucket/head_object.expected_bucket_owner\nbucket/head_object expected_bucket_owner","url":"bucket/head_object.html#expected_bucket_owner"},{"doc":"bucket/head_object","title":"if_match","content":"pub fn if_match(\n  builder: RequestBuilder,\n  etag etag: String,\n) -&gt; RequestBuilder\n Return the object only if its entity tag (ETag) is the same as the one\n specified; otherwise, return a 412 (precondition failed) error.\n \n If both of the If-Match and If-Unmodified-Since headers are present in the\n request as follows:\n \n If-Match condition evaluates to true, and;\n If-Unmodified-Since condition evaluates to false;\n Then Amazon S3 returns 200 OK and the data requested.\n \n For more information about conditional requests, see RFC 7232.\n &lt;https://datatracker.ietf.org/doc/html/rfc7232&gt;\nSynonyms:\nbucket/head_object.if_match\nbucket/head_object if_match","url":"bucket/head_object.html#if_match"},{"doc":"bucket/head_object","title":"request","content":"pub fn request(\n  bucket bucket: String,\n  key key: String,\n) -&gt; RequestBuilder\n\nSynonyms:\nbucket/head_object.request\nbucket/head_object request","url":"bucket/head_object.html#request"},{"doc":"bucket/head_object","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(Outcome, BucketError)\n\nSynonyms:\nbucket/head_object.response\nbucket/head_object response","url":"bucket/head_object.html#response"},{"doc":"bucket/head_object","title":"bucket/head_object","content":" &lt;https://docs.aws.amazon.com/AmazonS3/latest/API/API_HeadObject.html&gt;","url":"bucket/head_object.html"},{"doc":"bucket/list_buckets","title":"ListAllMyBucketsResult","content":"pub type ListAllMyBucketsResult {\n  ListAllMyBucketsResult(\n    buckets: List(Bucket),\n    continuation_token: Option(String),\n  )\n}\n\nListAllMyBucketsResult(\n  buckets: List(Bucket),\n  continuation_token: Option(String),\n)\n\n\nSynonyms:\nbucket/list_buckets.ListAllMyBucketsResult\nbucket/list_buckets ListAllMyBucketsResult","url":"bucket/list_buckets.html#ListAllMyBucketsResult"},{"doc":"bucket/list_buckets","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(\n    continuation_token: Option(String),\n    max_buckets: Option(Int),\n  )\n}\n The parameters for the API request\nRequestBuilder(\n  continuation_token: Option(String),\n  max_buckets: Option(Int),\n)\n\n\nSynonyms:\nbucket/list_buckets.RequestBuilder\nbucket/list_buckets RequestBuilder","url":"bucket/list_buckets.html#RequestBuilder"},{"doc":"bucket/list_buckets","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/list_buckets.build\nbucket/list_buckets build","url":"bucket/list_buckets.html#build"},{"doc":"bucket/list_buckets","title":"continuation_token","content":"pub fn continuation_token(\n  builder: RequestBuilder,\n  token: String,\n) -&gt; RequestBuilder\n ContinuationToken indicates to Amazon S3 that the list is being continued\n on this bucket with a token. ContinuationToken is obfuscated and is not a\n real key. You can use this ContinuationToken for pagination of the list\n results.\nSynonyms:\nbucket/list_buckets.continuation_token\nbucket/list_buckets continuation_token","url":"bucket/list_buckets.html#continuation_token"},{"doc":"bucket/list_buckets","title":"max_buckets","content":"pub fn max_buckets(\n  builder: RequestBuilder,\n  count: Int,\n) -&gt; RequestBuilder\n Maximum number of buckets to be returned in response. When the number is\n more than the count of buckets that are owned by an AWS account, return all\n the buckets in response.\n \n Valid Range: Minimum value of 1. Maximum value of 1000.\n\nSynonyms:\nbucket/list_buckets.max_buckets\nbucket/list_buckets max_buckets","url":"bucket/list_buckets.html#max_buckets"},{"doc":"bucket/list_buckets","title":"request","content":"pub fn request() -&gt; RequestBuilder\n\nSynonyms:\nbucket/list_buckets.request\nbucket/list_buckets request","url":"bucket/list_buckets.html#request"},{"doc":"bucket/list_buckets","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(ListAllMyBucketsResult, BucketError)\n\nSynonyms:\nbucket/list_buckets.response\nbucket/list_buckets response","url":"bucket/list_buckets.html#response"},{"doc":"bucket/list_buckets","title":"bucket/list_buckets","content":"","url":"bucket/list_buckets.html"},{"doc":"bucket/list_objects","title":"ListObjectsResult","content":"pub type ListObjectsResult {\n  ListObjectsResult(is_truncated: Bool, contents: List(Object))\n}\n\nListObjectsResult(is_truncated: Bool, contents: List(Object))\n\n\nSynonyms:\nbucket/list_objects.ListObjectsResult\nbucket/list_objects ListObjectsResult","url":"bucket/list_objects.html#ListObjectsResult"},{"doc":"bucket/list_objects","title":"Object","content":"pub type Object {\n  Object(\n    key: String,\n    last_modified: String,\n    etag: String,\n    size: Int,\n  )\n}\n\nObject(\n  key: String,\n  last_modified: String,\n  etag: String,\n  size: Int,\n)\n\n\nSynonyms:\nbucket/list_objects.Object\nbucket/list_objects Object","url":"bucket/list_objects.html#Object"},{"doc":"bucket/list_objects","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(\n    bucket: String,\n    prefix: Option(String),\n    start_after: Option(String),\n    max_keys: Option(Int),\n  )\n}\n The parameters for the API request\nRequestBuilder(\n  bucket: String,\n  prefix: Option(String),\n  start_after: Option(String),\n  max_keys: Option(Int),\n)\n\n\nSynonyms:\nbucket/list_objects.RequestBuilder\nbucket/list_objects RequestBuilder","url":"bucket/list_objects.html#RequestBuilder"},{"doc":"bucket/list_objects","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/list_objects.build\nbucket/list_objects build","url":"bucket/list_objects.html#build"},{"doc":"bucket/list_objects","title":"prefix","content":"pub fn prefix(\n  builder: RequestBuilder,\n  prefix: String,\n) -&gt; RequestBuilder\n Limits the response to keys that begin with the specified prefix.\n\nSynonyms:\nbucket/list_objects.prefix\nbucket/list_objects prefix","url":"bucket/list_objects.html#prefix"},{"doc":"bucket/list_objects","title":"request","content":"pub fn request(bucket: String) -&gt; RequestBuilder\n\nSynonyms:\nbucket/list_objects.request\nbucket/list_objects request","url":"bucket/list_objects.html#request"},{"doc":"bucket/list_objects","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(ListObjectsResult, BucketError)\n\nSynonyms:\nbucket/list_objects.response\nbucket/list_objects response","url":"bucket/list_objects.html#response"},{"doc":"bucket/list_objects","title":"start_after","content":"pub fn start_after(\n  builder: RequestBuilder,\n  key: String,\n) -&gt; RequestBuilder\n StartAfter is where you want Amazon S3 to start listing from. Amazon S3\n starts listing after this specified key. StartAfter can be any key in the\n bucket.\n\nSynonyms:\nbucket/list_objects.start_after\nbucket/list_objects start_after","url":"bucket/list_objects.html#start_after"},{"doc":"bucket/list_objects","title":"bucket/list_objects","content":"","url":"bucket/list_objects.html"},{"doc":"bucket/put_object","title":"PutObjectResult","content":"pub type PutObjectResult {\n  PutObjectResult(etag: String)\n}\n\nPutObjectResult(etag: String)\n\n\nSynonyms:\nbucket/put_object.PutObjectResult\nbucket/put_object PutObjectResult","url":"bucket/put_object.html#PutObjectResult"},{"doc":"bucket/put_object","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(bucket: String, key: String, body: BitArray)\n}\n The parameters for the API request\nRequestBuilder(bucket: String, key: String, body: BitArray)\n\n\nSynonyms:\nbucket/put_object.RequestBuilder\nbucket/put_object RequestBuilder","url":"bucket/put_object.html#RequestBuilder"},{"doc":"bucket/put_object","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/put_object.build\nbucket/put_object build","url":"bucket/put_object.html#build"},{"doc":"bucket/put_object","title":"request","content":"pub fn request(\n  bucket bucket: String,\n  key key: String,\n  body body: BitArray,\n) -&gt; RequestBuilder\n\nSynonyms:\nbucket/put_object.request\nbucket/put_object request","url":"bucket/put_object.html#request"},{"doc":"bucket/put_object","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(PutObjectResult, BucketError)\n\nSynonyms:\nbucket/put_object.response\nbucket/put_object response","url":"bucket/put_object.html#response"},{"doc":"bucket/put_object","title":"bucket/put_object","content":"","url":"bucket/put_object.html"},{"doc":"bucket/upload_part","title":"RequestBuilder","content":"pub type RequestBuilder {\n  RequestBuilder(\n    bucket: String,\n    key: String,\n    upload_id: String,\n    part_number: Int,\n    body: BitArray,\n  )\n}\n The parameters for the API request\n\n The `part_number` can be any number from 1 to 10,000, inclusive. A part number uniquely identifies a part and also defines its position within the object being created. If you upload a new part using the same part number that was used with a previous part, the previously uploaded part is overwritten.\nRequestBuilder(\n  bucket: String,\n  key: String,\n  upload_id: String,\n  part_number: Int,\n  body: BitArray,\n)\n\n\nSynonyms:\nbucket/upload_part.RequestBuilder\nbucket/upload_part RequestBuilder","url":"bucket/upload_part.html#RequestBuilder"},{"doc":"bucket/upload_part","title":"UploadPartResult","content":"pub type UploadPartResult {\n  UploadPartResult(etag: String)\n}\n\nUploadPartResult(etag: String)\n\n\nSynonyms:\nbucket/upload_part.UploadPartResult\nbucket/upload_part UploadPartResult","url":"bucket/upload_part.html#UploadPartResult"},{"doc":"bucket/upload_part","title":"build","content":"pub fn build(\n  builder: RequestBuilder,\n  creds: Credentials,\n) -&gt; Request(BitArray)\n\nSynonyms:\nbucket/upload_part.build\nbucket/upload_part build","url":"bucket/upload_part.html#build"},{"doc":"bucket/upload_part","title":"request","content":"pub fn request(\n  bucket bucket: String,\n  key key: String,\n  upload_id upload_id: String,\n  part_number part_number: Int,\n  body body: BitArray,\n) -&gt; RequestBuilder\n\nSynonyms:\nbucket/upload_part.request\nbucket/upload_part request","url":"bucket/upload_part.html#request"},{"doc":"bucket/upload_part","title":"response","content":"pub fn response(\n  response: Response(BitArray),\n) -&gt; Result(UploadPartResult, BucketError)\n\nSynonyms:\nbucket/upload_part.response\nbucket/upload_part response","url":"bucket/upload_part.html#response"},{"doc":"bucket/upload_part","title":"bucket/upload_part","content":" &lt;https://docs.aws.amazon.com/AmazonS3/latest/API/API_UploadPart.html&gt;","url":"bucket/upload_part.html"}]);